
screen=class()

function screen:init()
    self.pct=1
    self.maxSpeed=.3
    self.count=100
    self.lowScore=0
    self.showMenu=true
    self.youWon=false
    self.hitWall=false
    self.youLost=false
    self.hgx=Gravity.x
    self.paused=false
    self.playGame=false
    self:getLowScore()
end

function screen:getLowScore()
    self.lowScore=readProjectData("Low_Score",self.count)
end

function screen:map()
    if mn.showMap=="Off" then
        fill(255)
        text("Tap here for map",WIDTH-80,HEIGHT-40)
        return
    end
    if mn.flying=="Off" then
        stroke(204, 86, 15, 197)
        strokeWidth(5)
        for a,b in ipairs(wa.wallTab) do
            if a > 4 then
            xPos=b.xp+210
            yPos=b.zp+210
            xLen=b.xs/2
            if xLen==1 then
                xLen=0
            end
            yLen=b.zs/2
            if yLen==1 then
                yLen=0
            end
            line(WIDTH-10-(xPos-xLen)/2,(yPos-yLen)/2+HEIGHT-220,
            WIDTH-10-(xPos+xLen)/2,(yPos+yLen)/2+HEIGHT-220)
            end  
        end
    end
    if mn.showMap == "On" then
        pushStyle()
        strokeWidth(5)
        stroke(89, 99, 75, 178)
        fill(204, 228, 219, 13)
        rect(WIDTH-222,HEIGHT-222,214,214)
        strokeWidth(2)
        stroke(255, 0, 0, 169)
        ellipse(WIDTH-10-(sh.cameraX+210)/2,(sh.cameraZ+210)/2+HEIGHT-220,10)
        fill(45, 0)
        stroke(153, 223, 191, 227)
        strokeWidth(2)
        for a,b in pairs(gb.greenBallsTab) do
            ellipse(WIDTH-10-(b.ent.position.x+210)/2,
            HEIGHT-220+(b.ent.position.z+210)/2,8)
        end
        popStyle()
    end
end

function screen:fuel()
    if mn.showFuel=="Off" then
        return
    end
    if sh.speed>0 then
        self.pct=self.pct-.0002
    end
    fill(255)
    rect(20,HEIGHT/2+100,20,200)
    if self.pct<.1 then
        fill(255, 0, 0)
    elseif self.pct<.25 then
        fill(255, 255, 0)
    else
        fill(0,255,0)
    end
    rect(20,HEIGHT/2+100,20,200*self.pct)
    fill(0, 0, 255)
    text(string.format("%3.1f",self.pct*100),30,HEIGHT/2+90)
    if self.pct<=0 then
        self.pct=0
    end
end

function screen:createFloor()
    local f1=scene:entity()
    f1.model = craft.model.cube(vec3(400,1,400))
    f1.position=vec3(0,-.5,0)
    f1.material = craft.material(asset.builtin.Materials.Standard)
    f1.material.map = readImage(asset.builtin.Surfaces.Desert_Cliff_Color)
    f1.material.offsetRepeat=vec4(0,0,50,50)
end

function screen:createCraftTerrain()
    local x = x or 0
    local z = z or 0
    local seed = math.random(5000)
    terrainModel = makeCraftTerrain(600,400,7.5,seed,5)
    ct=scene:entity()
    ct.model = terrainModel
    ct.position = vec3(x - 400 / 2, -10.25, z - 400 / 2) -- Adjust as necessary
    ct.material = craft.material(asset.builtin.Materials.Basic)
    ct.material.map = readImage(asset.builtin.Surfaces.Desert_Cliff_Color)    
    ct.material.roughness = 100
    ct.material.roughnessMap = readImage(asset.builtin.Surfaces.Desert_Cliff_Roughness)
    ct.material.normalMap = readImage(asset.builtin.Surfaces.Desert_Cliff_Normal)
    ct.material.aoMap = readImage(asset.builtin.Surfaces.Desert_Cliff_AO)
    ct.material.aoMapIntensity = 0.5
    ct.material.offsetRepeat=vec4(0,0,6,6)
end

function screen:createLightConditions()
    scene.sun.rotation = quat.eulerAngles(45,-45,45)   
    scene.ambientColor = color(90, 127, 141)   
    scene.sky.material.sky = color(0)       
    scene.sky.material.horizon = color(27, 38, 52)       
    scene.sky.material.ground = color(0)
    cameraComponent = scene.camera:get(craft.camera)
    cameraComponent.hdr = true
    cameraComponent.colorTextureEnabled = true
    sunLight = scene.sun:get(craft.light)
    sunLight.intensity = 0.75
    bloom = craft.bloomEffect()
    cameraComponent:addPostEffect(bloom)
    bloom.threshold = 4
    bloom.intensity = 1.2
    bloom.softThreshold = 0.4
    bloom.iterations = 8
end

function screen:status()
    if self.showMenu then
        mn:draw()
        self.playGame=false
    end
    if self.youLost then
        sc:youLostFunc()
        self.playGame=false
    end
    if self.hitWall then
        sc:hitWallFunc()
        self.playGame=false
    end
    if self.youWon then
        sc:youWonFunc()
        self.playGame=false
    end
end

function screen:youLostFunc()
    fill(255,0,0)
    text("YOU LOST!",WIDTH/2,HEIGHT/2+150)
    text("Balls left "..gb.ballsLeft,WIDTH/2,HEIGHT/2+100)
    text("Low score   "..string.format("%d",self.lowScore),WIDTH/2,HEIGHT/2+50)
    text("Hold the ipad comfortable then",WIDTH/2,HEIGHT/2)
    text("Double tap the screen to play again.",WIDTH/2,HEIGHT/2-50)
end

function screen:hitWallFunc()
    sprite(asset.builtin.Tyrian_Remastered.Explosion_Huge,WIDTH/2,HEIGHT/2,500,500)
    fill(255,0,0)
    text("Hold the ipad comfortable then",WIDTH/2,HEIGHT/2+50)
    text("Double tap the screen to continue.",WIDTH/2,HEIGHT/2)
    if self.pct==0 then
        text("Out of fuel",WIDTH/2,HEIGHT/2-80)
    end
end

function screen:youWonFunc()
    fill(255,0,0)
    text("YOU WON!",WIDTH/2,HEIGHT/2+100)
    text("Hold the ipad comfortable then",WIDTH/2,HEIGHT/2+50)
    text("Double tap the screen to play again.",WIDTH/2,HEIGHT/2)
end

function screen:setup1()
    scene = craft.scene()
    scene.camera.position = vec3(cameraX,0,cameraZ)
    scene.camera.eulerAngles=vec3(ex,ey,ez)
    scene.sun.rotation = quat.eulerAngles(45,0,45)
    scene.ambientColor = color(90,90,90)
    
    skyMaterial = scene.sky.material
    skyMaterial.horizon = color(255)
    
    wa:createWall(0,0,200,400,50,2)
    wa:createWall(200,0,0,2,50,400)
    wa:createWall(0,0,-200,404,50,2)
    wa:createWall(-200,0,0,2,50,400)
    
    gb:create()
    
    --self:createFloor()
    self:createCraftTerrain()
    self:createLightConditions()
    self.lowScore=readProjectData("Low_Score",self.count)
end

function screen:play()
    if self.playGame then
        update(DeltaTime)
        scene:draw()
        fill(255)
        if self.paused then
            text("PAUSED",WIDTH/2,HEIGHT*.7)
            text("Triple tap to restart.",WIDTH/2,HEIGHT*.7-20)
        else
            text("Triple tap to pause.",WIDTH/2,HEIGHT-10)
            text("Low Score  "..string.format("%d",self.lowScore),80,HEIGHT-60)
            sh:updateCamera()
            sh:tilt()
            sh:draw()
            sh:levels()
            self:fuel()
            self:map()
            gb:collision()
            gb:move()
            wa:collision()
        end
    end
end

function screen:touched(t)
    if self.showMenu then
        mn:touched(t)
        return
    end
    if t.x>WIDTH-200 and t.y>HEIGHT-200 then
        if mn.showMap=="Off" then
            mn.showMap="On"
        else
            mn.showMap="Off"
        end
        return
    end
    if t.tapCount==3 then
        sh.ang=0
        self.paused=not self.paused
    end
    if t.tapCount==2 then
        if self.youWon then
            viewer.restart()
        elseif self.youLost then
            viewer.restart()
        elseif self.hitWall then
            self.hitWall=false
            self.hgx=Gravity.x
            sh.cameraX,sh.cameraZ=-195,-195
            sh.ships=sh.ships-1
            sh.speed,sh.ey,sh.ang=0,45,0
            self.pct=1
            self.playGame=true
        end
    else
        sh.ang=0
        sh.gyOrig=Gravity.y
        if sh.speed==0 then
            sh.speed=self.maxSpeed
        end
    end
end
